/*!	\file spi.c
	\brief SPI read and write functions

*/
/* Some functions for SPI master with ATmega48/88/168/328

	MRU JR 101219
	101219 Changed so that no bits in SPCR are changed, and I'm master

	They assume that the SPI has been initialised, and that the
	SPI peripheral is enabled. At the moment this is for master
	The caller must enable and disable the SPI peripheral, and set
	the CPHA/CPOL bits as required by the peripheral
*/
#include <avr/io.h>
#include "config.h"
#ifdef SPI_DEV
#include "SPI.h"

/*!
	\return SPDR, this is the previous value from the slave
*/
uint8_t SPIread(void)
{
	return SPDR;
} /* SPIread */

/*!
	\brief Write to slave SPI device
	\param[in] data Value to be written to the slave
	\return SPDR, the data from the slave
*/
uint8_t SPIwrite(uint8_t data)
{
	SPDR = data;
	while (!(SPSR & (1 << SPIF)))	/* wait for it to disappear */
		;
	return SPDR;									/* data from the slave */
} /* SPIwrite */

#endif /* SPI_DEV */
