/*! \file spi.h
	\brief Header for SPI master with ATmega48/88/168/328, no interrupt
*/
/*
	MRU JR 1110704
	110704 Removed SPI_SET
	101220 Added SPI_SET
	101219 Added SPI_PORT definition

*/
#ifndef _AVRSPI_H_
#define _AVRSPI_H_

#include <avr/io.h>
#include <inttypes.h>

/* Pin/register definitions for SPI, this is when I'm master SPI
	This is specific for ATmega48 etc.
*/
#define SPI_PORT	PORTB			/*!< Port for all SPI pins */
#define SPI_DDR 	DDRB			/*!< Data direction register for SPI */
#define SPI_PINR 	PINB			/*!< Pin register for SPI */
#define SPI_SS		PB2				/*!< Chip select, user control when master */
#define SPI_MOSI 	PB3				/*!< Set to output, data to slave */
#define SPI_MISO 	PB4				/*!< enable SPI makes this an input */
#define SPI_SCK 	PB5				/*!< Clock output */

/* Initialise SPI HW is INIT_SPI in SIMRCV.h */

/* SPIread returns the value in the SPDR */
uint8_t SPIread(void);

/* SPIwrite writes a byte to SPI, and returns the value which was
	shifted from the slave into the SPDR, might be needed
*/
uint8_t SPIwrite(uint8_t data);

#endif /* _AVRSPI_H_ */
